---
tags: post
layout: "layouts/article.njk"
title: "A Logo Design Process"
date: "2014-07-17"
meta:
  description: I wanted a new logo/branding for a redesign of this site and for other promotional crud. Here's a look into the creation process.
---

        <p class="entry-intro">
            As part of my site <a href="https://tylergaw.com/articles/how-i-start">redesign</a>
            I wanted new branding. It’s not really a logo I guess, but
            it’s what I’ll be using on this site and any other promotional crud that I make
            like business cards. This was a fun process that let me dive deeper
            into hand-lettering than I have before. Here’s a look into the design of the
            new logo from pencil sketch to final (enough) image.
        </p>
        <p>
            I’m not trying throw out everything and
            start from zero. Because of that, my first step was look at what I have now. My current
            logo appears in three variations. The largest appears
            on my homepage. On medium size screens a smaller, stacked
            version with "web" on top and "designer" below my name is shown. On small screens,
            a side-by-side version with my name on the left and "web designer" on the right is shown.
        </p>
        <figure>
            <img src="https://tylergaw.com/articles/assets/post-image-logo-process-existing.jpg" alt="">
            <figcaption>
                Variations of my current logo displayed at different screen sizes
            </figcation>
        </figure>

        <p>
            I always start as rough as possible. I grabbed the "Tyler Gaw" portion
            of the existing logo and plopped it into a new PSD. I didn’t have a
            plan for what I’d do with the logo so just started
            typing out different titles next to it in different typefaces to get
            things rolling. I tried side-by-side, top and bottom, serifs, sans-serifs, handwriting,
            pulling, prodding, stretching, scaling, etc. I let myself play and make
            as many ugly messes as I could.
        </p>
        <p>
            After a good amount of messin’ I landed on something that definitely
            wasn’t ready, but felt like a good path. My name with "Design & Development" and "Brooklyn NY, USA"
            below it. I added a slight angle to both sides to make it a more
            interesting.
        </p>

        <p>
            The image below shows that everything was out of whack, it’s
            not even fully readable. That was OK. It was enough that I could see
            where I wanted to go with it.
        </p>

        <figure>
            <img src="https://tylergaw.com/articles/assets/post-image-logo-process-roughage.jpg" alt="">
            <figcaption>
                The results of messing with the existing logo. This was bad on
                purpose. It got me started down the right path.
            </figcation>
        </figure>

        <p>
            In the existing logo I refer to myself as a "Web Designer". That feels like
            an accurate title because I design and
            write code, but I wanted to be more clear so I went with "Design & Development".
            Using "Web Designer"
            as a title I often have to answer; "no, not only design. I write code too".
        </p>

        <h2>Back to Sketching</h2>
        <p>
            The next step was to get off the computer and do some sketching. I gave
            myself some loose guides to follow for the width/height and for the
            shape the text would be in. I redrew the same thing five or six times
            until I got one that was close enough.
        </p>
        <figure>
            <img src="https://tylergaw.com/articles/assets/post-image-logo-process-sketches.jpg" alt="">
            <figcaption>
                Trying to get a solid sketch to start
            </figcation>
        </figure>

        <figure>
            <img src="https://tylergaw.com/articles/assets/post-image-logo-process-sketch.jpg" alt="">
            <figcaption>
                The close enough pencil &amp; Ink sketch that was used as a starting point in Illustrator
            </figcation>
        </figure>

        <h2>Moving Into Illustrator</h2>
        <p>
            I brought the close enough sketch into Illustrator and live traced it.
            The conversion to vector was as good as could be expected. With any
            hand-drawn text there are a lot of unneeded and rough points.
        </p>
        <p>
            I did a pass where I cleaned up the spacing and removed many points to
            make the letters of "Design &amp; Development" smoother. In the image
            below you can see some sharp edges in places on the "Tyler Gaw". Those
            were caused by me changing the height and rotation of different letters
            and portions of letters.
        </p>

        <p>
            When I thought I had the basic size and shape where I wanted it I
            brought it over to Photoshop and placed it in a very early layout of
            the new site.
        </p>

        <figure>
            <img src="https://tylergaw.com/articles/assets/post-image-logo-process-first-thought.jpg" alt="">
            <figcaption>
                This is what I originally imagined the logo would resemble. Very
                hand-drawn, close to my existing logo. There would still have been a lot of
                clean-up required for this to work.
            </figcation>
        </figure>
        <p>
            This felt wrong. It was too spindly. I didn’t feel like it was standing up on its own.
            Felt like it could get lost easily at smaller sizes. I wanted
            it to feel more involved, more interesting, just more.
        </p>

        <p>
            "What if I add some serifs?" I asked myself. I started with the "D"
            in "Design". I widened the stroke and added slight serifs to it.
            That’s what it needed. With that small change I could tell immediately that this was where
            it needed to go. That also let me know that I was in for a whole lot
            of tedious work as I would have to take the same steps for each letter.
        </p>

        <h2>The Work</h2>

        <p>
            It took me about about fours days to update all the letters. I
            always started by removing as many points as possible. A general rule
            I figured out was mo’ points, mo’ problems. Fewer points allow for
            smoother curves and fewer pinches and nicks where they aren’t wanted.
            After deleting the points it was a matter of moving them around until
            the stroke width and serifs matched the rest of the letters. I used
            some loose guides to keep the serif sizes similar, but since this is
            supposed to have a hand-drawn look I could take liberties with them.
        </p>

        <p>
            The removing, adding, and moving of points feels a lot like working with clay. You start with these
            rough shapes and you slowly push and pull and smooth it into the shape
            that you’re looking for. I’ve written about this process before
            for <a href="https://tylergaw.com/articles/slenderman">Slenderman</a>.
            For some reason it felt more like chiseling rock that time.
        </p>

        <p>
            As a way to check that things were shaping up correctly and as a break
            from tedium, I would often bring the logo into the rough layout in Photoshop.
            Looking at it as a raster image at the approximate size it would be
            displayed helped me make sure it was readable and looked how I wanted it.
            I worked on the letters in bursts. I would do a letter, maybe two. Then
            stop, get some air. Move it to Photoshop, check it, repeat.
        </p>
        <figure>
            <img src="https://tylergaw.com/articles/assets/post-image-logo-process-ani.gif" alt="">
            <figcaption>
                Animation showing the rough steps of the process
            </figcation>
        </figure>

        <p>
            I’m happy with how it’s turned out. I’m also working on colors
            for the redesign so I added bits of color to the logo and put it up on
            <a href="https://dribbble.com/shots/1644137-GAW-Mark-WIP">Dribbble</a> for feedback.
            From the beginning I’ve had my brain set on a red for some reason, but
            all of the feedback points to yellow. I’ve been playing with yellow
            as an accent color for the the rest of the site and it feels like it’s working so far.
        </p>

        <p>
            Here’s a final (as-of-right-now) version of the logo embedded as SVG.
            I removed the yellow drop shadow from my name that is shown in the Dribbble shot.
            It was kind of cool, but didn’t feel necessary. I think I can get more
            mileage out of the logo without it.
        </p>
        <figure>
            <svg version="1.1" xmlns="https://www.w3.org/2000/svg" xmlns:xlink="https://www.w3.org/1999/xlink" x="0px" y="0px"
     width="3267.3px" height="440px" viewBox="0 0 3267.3 2116.3" style="width:100%; height:auto; min-height:200px;background-color:#1e1e1d;"
     xml:space="preserve" title="Tyler Gaw Design & Development - Brooklyn, NY U.S.A.">
            <g id="Logo">
            	<path id="gaw-w" style="fill-rule:evenodd;clip-rule:evenodd;fill:#F9F9F9;" d="M2783.4,977c19.8,1,52-275.5,54.8-279.7
            		c3.2-4.7-29.4-47.2-22.1-47.5c1.6-0.1,96.1-21.8,124.4,0c8.3,6.4-19.9,14-15.8,33.3c9,41.6,87.5,202.7,94.3,204.2
            		c12.2,0-9.5-125.3-9.2-143c0.5-28.8-2.9-132.7-4-146.9c-1.5-19.3-6.5-110.3-6.5-127.6c0-79.5,2.8-178,6-199
            		c1.6-10.6-4-46.6-2.8-65.3c3.1-45.3-37.7-51.7-36.2-84.7c-0.8-8.4,152.9,15.5,151.1,18.2c-13.6,38.8-41.8,33.8-44.4,53.2
            		c-1.8,13.7-12.7,79.5-20.8,157.7c-0.4,0.4-3.7,78.6-2.4,103.1c1,19.4,10.8,100.4,10.6,106.2c-1.4,40,0.1,30.4,0.5,72
            		c0.2,19.8,15.4,82,11.2,111.1c-3.3,22.6,6.7,168.1,6,175c-2.1,20.1,41.9,30.9,39.5,55c-0.6,5.9-136.4,50.2-142.1,38.9
            		c-4.5-9,19.7-36.7,1.5-75c-10.4-21.7-28.6-52.9-45.2-89.6c-27.7-61.2-36.6-128.9-41.1-128.9c-5.7,0-4.7,67.5-15.5,142.2
            		c-11.9,82.7-35.1,174.1-28.5,192.3c-2.1,9.5-121.1,56.8-125.8,49.6c-3.2-4.9,11.9-62.1,9.7-74.8c-2.4-13.6-23.4-137.5-25.9-183.1
            		c-0.7-12.3-16.3-114.5-19.6-136.7c-3.2-21.2-15.4-94.7-17.4-102.9c-5.3-21.4-15.1-59.9-23.5-83.5c-5.9-16.4-8.4-33.8-13.4-50.5
            		c-5.3-18.1-28.4-138.5-32.8-154c-3.9-13.9-39.8-126.7-45.5-155.2c-1.9-9.4-41-58.8-44-68c-2.2-6.7,153.2,4.2,156,6
            		c17-4.9-30.3,61.4-29.7,65.5c1.8,11.2,34.8,135.9,37.7,144.7c8.1,24.5,27.5,129.3,30.4,145.8c2.7,15.3,48.6,274.5,47.7,289.9
            		c-0.7,12.1,6.1,92.2,4.7,115C2754.1,878.5,2763.9,976.5,2783.4,977z"/>
            	<path id="gaw-a" style="fill-rule:evenodd;clip-rule:evenodd;fill:#F9F9F9;" d="M2446.7,797.9c-17.4,2.8-66.3,24.6-74.6,26.4
            		c-15.5,3.4-88.7,13.5-93.8,17c-5.8,7.7,26.6,280.8,27,304c2,27,19.7,15.7,24.3,47.1c1.8,12.2-159.5,66.3-158.3,57.9
            		c2.4-15.8,18.3-34.1,21-49.8c2.7-15.8,21.6-110.2,22.2-126.1c0.2-5.5,0.1-11.1,1.1-16.5c5.1-27.7-8.3-171.9-5.7-199.8
            		c1.5-15.9,1.3-177.4,0.2-200.2c-1-19.8,2.8-291.5-1.3-310.9c-2.6-12.2-13.6-195.6-14.5-205.7c-1.1-12.5-26.4-44.2-26-57
            		c0-9.4,167,0.6,173,8c2.9,9.1-19.8,23.3-19,39c1.9,36.2,20.1,94.9,38,126.2c4.2,7.3,65.9,180.7,72.9,203.6
            		c3.3,10.9,58.6,132.3,62.7,157.7c3.1,19,21.2,109.6,21.4,128.8c0.2,18.2,41.2,314.4,40.3,332.7c-1.1,21.2,19,18,25.7,49
            		c1.2,5.8-133.2,45-135.9,40.3c-2.2-18.6,20.2-18.3,19.2-55.9C2464.6,1035.5,2450.9,797.2,2446.7,797.9z M2283.4,767.7
            		c1.9,1.2,66.9-1.9,79.3-6.7c10.3-3.9,72.2-22.5,71.9-31.5c-10.2-77.1-45.4-196.1-53.4-224.1c-2.7-9.3-69.2-225-71.8-232.2
            		c-3.5-9.5-46.9-117.3-52-117.8c-7-0.6-3.4,173.7-2,181c3.1,16.4,5.7,169.2,9.5,180.8C2270.7,535.4,2281.9,763.1,2283.4,767.7z"/>
            	<path id="gaw-g" style="fill-rule:evenodd;clip-rule:evenodd;fill:#F9F9F9;" d="M2005.4,258.9c-26.7-12.8-33.9-21.7-44.3-56.2
            		c-39.5-131.4-157.3-82.4-171-71.1c-5.9,4.1,24.3,560.6,23.9,586.6c-0.4,26.7-15.1,252.2-16.9,267.8c-0.2,1.9,1.4,55.8-1.6,80.6
            		c-2.6,21.5-40.2,246.2,24.8,237.6c50-6.6,114-76,133-121c9.5-17.6,27.9-395.9,23.7-395c-24,5.4-44.5,12.2-65.7,15.7
            		c-9.9,11.5-18.8,15.1-35.7,14.7c-4.8-0.3-2.2-95,1.3-98.2c5-8.7,44.7-6.6,72.7-7.5c21.1-1.6,77.5-10.4,78.1-8.9
            		c2.4,6.2,9.9,220.2,8,239.7c-1.4,14.3-2.7,348.2-15.4,350.5c-39.3,4.8-48.2-39.4-48.2-39.4c-5.8,18.2-19.8,70.3-62.1,82
            		c-16,0.3-125,54.7-159.8,48.6c-35-6.1-33.9-244-32.1-278c0.7-1.9,25.1-241.6,25.1-250c-0.1-5.6,3.2-206,3.1-231
            		c0-15.9-16.8-235.1-21.6-314c-3.4-19.1,3.2-170.9,10.1-181c14.8-30.9,15.5-67.7,139.2-67.7c84.9,0,78.3,38.2,102.6,41.5
            		c26.4,3.6,26.4-18.1,37-1.7C2014.7,120.5,2014.6,234.7,2005.4,258.9z"/>
            	<path id="tyler-r" style="fill-rule:evenodd;clip-rule:evenodd;fill:#F9F9F9;" d="M1488.2,432.6c-0.1,11.3-7.8,101.4-7.7,117.9
            		c0-21.1,2.1,242.4-18.5,333.9c-5.3,17.7-68.6,34.2-83.6,36.2c-0.3,0,74.8,23.7,69.8,79.7c-2.8,30.9-9.9,186-10.8,217
            		c-0.4,15.1-24.8,170.5,73.5,112.5c10.9-6.5,22.5-20.2,30.6-25.1c13.3-8,30.9,78.8-56.4,100.8c-4.7,0.1-106.3-36.7-113-40.9
            		c-13.9-29.4,1.3-79-1.3-104.3s9.2-222.5,9-229.7c-0.6-23.3-5.7-72.3-36.3-64.3c0,0-3.9,66.8-7.3,89.2
            		c-3.5,23.1-14.7,128.1-18,142.2c-3.1,13.2-6.6,83.7-4.1,95.8c0.8,4,14.5,53.9,10.2,55.2c-4.8,1.5-106.3-41.8-108.6-45.9
            		c-1.7-3.2,20.5-23.7,21.1-27.5c4.6-29.7,12.5-58.8,19.7-88c3.7-14.8,3.1-30.2,4.7-45.3c2.5-22.8,8.5-96.5,11.6-119.2
            		c2.4-17.5,6.1-41.9,7.4-59.6c0.3-4.8-0.4-9.7,0.1-14.5c6.6-64.2,4-192,4-177.4c0-20.8,1.4-41.3,2.6-61.9
            		c0.9-14.5,4.5-68.3,4.1-88.9c-0.4-21.4,4.6-220.4,4.3-225.6c-1.1-20.2-8.4-83.1-8.3-94.5c0.1-11-21.6-195.2-20-209.2
            		c0.3-2.9-32.7-17.4-31.2-28.4c5.2-4.1,68.9-6,74-6.1C1532,44.8,1480.6,248,1480.4,279.3C1480.4,296.4,1488.3,417,1488.2,432.6z
            		 M1348.5,854.7c0.4,5.6-3,4.7,33.9-0.4c21.1-2.9,36.1-104.4,38.1-122.4c2.4-20.9,9.6-148.1,9.7-150c0.3-10.9-0.6-148.6,0-161.5
            		c0.5-11.3-4.5-60.4-4-72c1.3-28,1.1-167.5-5.8-188.1c-6.7-20.1-3.3-34.9-21-48c-29.4-21.8-25.5-25.7-63-22
            		c0,0,10.5,96.4,10.5,114.5c0,17.7,8,233,8,260.5c0,29-4.3,139-4,143c1.2,19.3-0.9,78.2-2.4,88.2
            		C1344.5,721.8,1348.8,832.7,1348.5,854.7z"/>
            	<path id="tyler-e" style="fill-rule:evenodd;clip-rule:evenodd;fill:#F9F9F9;" d="M1022.7,887c10.8-55,1.6-97.9,3.7-117.4
            		c0.8-8.1-9.2-196.6-10.5-214.1c-1.6-20.7-22.1-261.9-22.2-293.8c0-13.6-10.8-144.4-9.4-156.7c-1-20.6-41.9-15.3-42.2-35.7
            		c0-4.1,76.4-4.4,84.7-4.3c10.6,0.1,45.8-1.2,52.6,0.4c4.2,1,73.9-2.3,85.8-2.2c5.4,0,11.8,63.4-4.8,62.4c-16-1.3,28-32-109.3-32
            		c0.1,6,21.3,212.8,26.7,265.3c2.5,52.5,11.3,212.2,12.7,236.9c0.5,10.2,6.7,160.8,4,178.4c-2.2,13.9-2.9,75.6-4.6,88.3
            		c-1,7.9,53.3-3.2,74.6,1.7c0.6,0.1,1.9,76.8-5,74.3c-17.8-6.3-80.4-14.9-81.9-11c-2.7,7.5-2.7,100-9.4,138
            		c-5.1,24.9-11.8,93.4-15.7,118.5c1.1,4.2,69.4,21.7,81,26.5c4,1.7,27.1-1.9,31.7-2.7c3.8-0.7-2.4,95.9-6.7,94.8
            		c-4.2-1-112-41.6-122.5-45.5c-10.1-3.7-91.4-29-91.8-29c-9-11,33.3-56.3,33.3-56.3c4.8-9.3,10.6-46,12.9-67.7
            		C990.7,1100.5,1019.7,913.1,1022.7,887z"/>
            	<path id="tyler-l" style="fill-rule:evenodd;clip-rule:evenodd;fill:#F9F9F9;" d="M891.5,1107.5c-0.6,15.6,1,118.3-5.5,115.8
            		c-8.7-3.3-116.2-44.4-137.3-48.9c-3.2-0.7-98-28.7-101.3-29.1c-0.4-25.7,51.8-47.8,52.6-54.6c3.4-23,29.1-94.3,29.6-97.7
            		c3.4-22.4,19.3-61.8,20.8-84.3c1.6-22.8,6.3-60.8,8.3-83.7c1.5-16.7,27.3-180.5,28.7-195.7c0.9-9.5-2.9-28.5-1.3-38
            		c4-23.9-7.1-253.7-7.3-272.3c-0.3-20.7-0.8-38.1-3-58.7c-1.5-14.1,10.9-143.1,8.3-157c-1.6-8.6-33.7-14.7-33.7-28.4
            		c0,0,60.1-0.3,77.1-2.8s55.3,2.8,55.3,2.8c-0.7,19.1-36.2,19.8-33.8,37.1c2.1,12.1-1.1,141-0.2,155c1.7,25.7,3.1,62.1,3.3,77.3
            		c0.4,23.5,4.7,93.1,6.7,111c1.8,15.9,1.2,125.8,0,138c-1.4,14-9.9,124.2-12,157.7c-1.7,27.6-6.2,54.7-11.2,82
            		c-2.4,13.3-8.4,57.9-9.8,80.7c-1.4,22.1-15.6,73.4-17,81.3c-2.4,13.7-11.5,36.8-13,50.7c-4.1,38-10.1,61.7-10.1,61.7
            		c32.7,13.5,36.3,19.4,53.3,24.7C859.2,1138.4,874.2,1104.5,891.5,1107.5z"/>
            	<path id="tyler-y" style="fill-rule:evenodd;clip-rule:evenodd;fill:#F9F9F9;" d="M711.5,85.9c-3.3,22.8-22.1,14-29.5,36.5
            		c-4.2,12.7-17.1,70.2-21,83c-3.2,10.8-31.8,102.6-35,108c-3.5,5.9-50.2,223.8-52.5,228.9c-4.1,9.1-7.5,47.5-8.8,54.3
            		c-5.2,26.6-2.2,60.1-1.3,93.1c-3.7,24.5-9.2,160.9-10.4,182.9c-0.7,14.5-7.7,56.3-10.3,70.7c-0.9,4.8-8,115.5-6.8,131.8
            		c0.5,7.1,15.8,27.9,12.5,49.2c0,0-158.9-55.2-159.7-61.3c4-10.7,27.3-10.7,36.7-21.5c5.9-10.9,27.9-44.5,29-63.5
            		c0.7-11.4,15.3-61,20-78c1.3-4.8,16.3-97.8,17-123c0.6-20,0.5-84.3,4-113.9c2.1-44.7-6.3-48.6-7-75.9c-1.9-31.2,2-87-4-106.7
            		c-5.1-16.5-35.8-223.5-40.4-245.1c-3.6-17.3-13.7-100-22.3-118.4c-4.4-9.3-32.6-15-37.7-24c-2.4-4.3,94.1-8.3,95.5-6.2
            		c1.8,4.6-26.1,18.4-22,34.7c12.4,49,23.4,136.1,27,151.5c4.9,20.8,38.5,222.8,42.5,222.9c3.9,0.1,34.7-184.7,39.5-195.9
            		c9.4-22.1,36.9-164.3,42.4-181.5c4.5-14.3-21.9-29-23.4-35.5c-0.4-2,30.7,3.9,61.8,0.5C660,82,711.4,83.9,711.5,85.9z"/>
            	<path id="tyler-t" style="fill-rule:evenodd;clip-rule:evenodd;fill:#F9F9F9;" d="M137.7,929.3c8.4-14,28.7-258.7,31.3-277.9
            		c2-14.3,8.4-296.9,7.7-308.6s-3-185.9,0.7-205.2c0,0-42.4,2.7-66,6.9c-9.1,0.2-41.9,32.7-50.4,35.8c-2.6,1,6.8-62,9-63.7
            		c11.7-3.6,21.2-1.8,33.9-1.2c8.8,0.4,84.5-4.5,84.5-4.5s95.8-11.7,119.3-10.8c9.7,0.4,32.9-1.3,35-1.2c6.3,0.4,16.3,69.9,10,69.4
            		c-5.7-0.4-38.2-34.7-46-35.3c-16.8-1.5-56.1,1.7-56.1,1.7s6.2,223.5,8.1,245.7c-0.5,15.5-6.7,98.5-7.9,110.6
            		c-1.8,17.9,1.1,95.3-0.7,108.8c-2.7,20.9-11.2,347.1-11.3,356.5c-0.2,10,24.7,56.6,16.7,72c0,0-155-53.8-153.9-67
            		C105.2,951,135.3,935.7,137.7,929.3z"/>
            	<path id="dev-t" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M3188.7,1119.3c0,0,2.3,33.9-1.9,32.8
            		c-3.8,1.2-6.5-6.5-33.3,1.8c-2.2,0.7-1.7,149.2-5,168.2c-6.1,35.3-4,64.6-7.2,105.9c-2,26.2,3.4,52.1,1.1,78.2
            		c-1.7,19.3,0.9,38.5,2.3,57.8c1.6,21.2,3.6,42.4,5.4,63.6c2.5,28.8,8.1,171.8,10.7,187.7c1,4.5,16.6,14.5,15.4,21.9
            		c-1,1.7-63.1,2.5-62.8,0.6c2.3-12.3,13.6-19.5,13.9-24c1.1-13.8-1.2-124.6-1.7-153.8c-0.2-15-11.2-104.7-10.1-135
            		c0.9-23.8-4.3-47.7-0.5-71.3c3-18.4,3.5-87.9,5.9-104.2c2.1-14.5,2.8-28.6,4-43.3c1-12.9,4.7-148.5,2.7-148
            		c-36.3,9.2-27.3,17.7-32,19.8c-0.9,0.8-8.9-27.4-7.9-28.5c9.2-5.8,17.5-9,27.2-11.1c17.8-3.8,37.1-11.3,55.8-16.4
            		C3175.4,1121.5,3181.7,1118.9,3188.7,1119.3z"/>
            	<path id="dev-n" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M3040.2,1764.4c3.4-2.8-2.9-89.2-2.7-107.3
            		c0.2-19.2-4.3-38.1-4.6-57.2c-0.2-14.2-6.9-162.2-5-179c3.4-30.2-2-219.6-0.9-235.3c-4,0-15.1-4.8-19-10.3
            		c-1.2-4,52.4-17.3,52.2-15.7c3.1,12-9.8,11.9-9.2,23.5c0.8,8.2,3.9,123,1.8,143c-1.5,13.9,2.1,57.9,0.1,71.8
            		c-2.6,18.1,1.3,158.1,1.2,177.1c-0.2,27.7,7.3,219.9,8.4,238.2c0.1,2.7,15.9,17,14.3,23.9c-0.3,1.2-60.3,1.9-60.7-0.2
            		c-1.5-8.9,9.8-18.1,9.4-24.1c-1-14.6-11-76.9-14.5-89.6c-4.9-17.3-17.5-88-18-103.1c-0.6-18.7-14.1-164.6-15.4-190
            		c-0.9-17.7-17.8-178.4-24-176.2c-9.5,1.5,4.7,209.8,5.2,218.7c1.3,23.8-0.8,159.6-0.6,171.2c0.5,20.1,0.5,145.1-0.9,167.9
            		c0.1,5.2,14.1,15.5,16.5,25.2c0.8,3.3-56.9,3-56.8,0.4c-1.7-13.7,10.3-12.4,10.5-24.5c1.7-81.4,7.9-360.4,5.6-396.4
            		c-0.6-23.9-5.2-193.3-6.7-207.2c-0.8-4.4-12-8.2-15.1-15.1c-0.1-2.7,42.8-11.7,44.4-9.2c7.9,16.2,26.3,58.5,29.1,77.2
            		c5.5,37,21.6,243.3,25.5,266S3037.4,1762.4,3040.2,1764.4z"/>
            	<path id="dev-e-3" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M2800.8,1629.3c1.5-17.2-0.2-38.2,1.5-55.3
            		c5.3-53.1,5.7-217.8,4.3-229c-0.5-3.6-5.7-90.3-6.2-94.7c-0.9-1.7-14.9,1.6-14.9,1.6c-1.4-12.2-3.5-20.7-3.5-20.7
            		c26.5-11.5,79.9-26.6,90.7-29.9c4.9-1.5,8.5,36.7,7.6,39c-1,1.6-5.3-8-15.5-7.8c-15.8,0.3-31.5,7.3-38.7,10.8
            		c-1.9,1,0,53.8,2.7,65.8c3.6,16.3,3.8,72.1,3.5,92.7c-0.4,22.5,1.4,60.9,0.2,68.6c-2.8,18.4-2.7,30.9-3.2,49.5
            		c-0.4,15.2-1.8,31,0,31.2c23.9,1,33.9-6.4,41.6-5.8c0.8,0.8,2.5,37.2-2.1,36.7c-6.2-0.5-21-7.2-42.2-4.5
            		c-1.8-0.3-4.4,236.6-0.1,236.4c6.4-0.2,29,1.3,35.2,1.2c10.6,0,8.4-11.2,18.8-10c4.1,0.5,0.4,36.6-1,36.7
            		c-10.5-1.1-81.9-1.7-87.2-2c-0.4,0-4.6-10.4-1.6-25.1c0.5-2.3,10.2-1.6,10.2-1.6C2801.9,1760,2800.2,1636.5,2800.8,1629.3z"/>
            	<path id="dev-m" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M2659.8,1551.3c-0.1-7.7,6.7-11.2,6.6-16
            		c-0.3-18.9-25.2-164-27.5-163.5s-0.3,96.4-1.4,107.3c-1.2,11.6,0.5,23.4,0.3,35.1c-0.1,7.2,0,100.8-3.4,122.1
            		c-1.6,10.1-1.6,138.8-3.2,181.6c-0.3,6.9,11.2,9.3,9.9,19.7c-0.6,1.8-49.5,2.9-49.3,0.2c-0.1-8.6,7.7-11.6,8.7-16.6
            		c2.9-18.8,5.1-138.8,7.6-157.6c2.9-21.2,1.6-120.6,2.6-137.1c0.8-14.1,0-46.7-0.1-55.1c-0.1-35.5,7-99,4.4-134.5
            		c-0.9-12.7-2-26.6-4.1-41.6c-0.3-2-16-5.5-15-11.5c0.5-2.5,56-21.2,57-17.5c0.7,2.6-6.1,17.5-5.5,22c0.2,1.7-4.6,13.5,2.2,55.2
            		c0.6,7.3,32.1,157.9,32.1,157.9c4-4,13.9-130.3,18.6-179.4c4.1-42.5,5.4-42.8,6-55.8c-0.6-5.4-12.1-6.3-12-12.9
            		c1.1-3.5,47.3-18,47.5-15.1c1.6,7.4-7.6,14.4-7.5,21c-0.1,6.1,8.3,106.7,9.6,124.8c1.7,24.5,5.9,72,3.2,96.4
            		c-2.8,26-0.2,43.1-2.9,69.1c-1,9.9,2.8,52.9,1.1,62.8c-3.8,23.6-0.2,181.1-1.6,205c-0.2,6.3,9.5,9,8.9,21.1
            		c0.2,2.5-49.6,2.5-51.2,0c-1.7-7.2,13.8-12.4,13.8-21.2c0.2-36.6-1.2-164.8,4-201c4.4-30.4,0-84,3.3-114.5
            		c2.5-23,1.7-136.4-0.9-159.5c-0.5-4.5-9.2,83.3-10.5,93.1c-1.3,17.2-10.5,65.1-16.5,94.9c-0.8,4.5,6.3,6.3,6.4,13.5
            		C2701.3,1547.1,2660.9,1555.3,2659.8,1551.3z"/>
            	<path id="dev-p" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M2577.5,1532.5c0.2,11.4-0.3,32.8-1.6,44.2
            		c-3.7,31.6-5.6,40.2-54,40.9c-0.8,0.5-2.8,78.7-2.7,94c0.1,12.6,1.4,25.2,0.2,37.7c-1.4,14.2,2,54.6-0.2,68.6
            		c-1.7,10.7,12.4,11.8,11.1,21.1c-0.3,2.2-54.9,4.2-55.2,1c-0.6-8,12.9-12.3,13.8-19.9c1.6-14.2,3.2-39.4,5.4-53.5
            		c4.4-27.4,2.8-55.1,4.3-82.5c0.2-3.8-0.9-44.7-0.3-48.5c1-6.6-2.2-59.7-1.1-77c1.4-23.5-0.2-46.8-0.7-70.1
            		c-0.5-21.7-5.2-40.3-7.3-61.8c-2-20.6-6.3-67-11.4-95.1c0,0-11.1,4.8-11.9,1.4c-0.4-1.9-11.3-14-10.6-14.7
            		c11.4-5.4,59.6-17.9,72.5-19.7c9.5-1.3,15.8,2.5,22,10c6.8,8.3,9.9,21.7,13,31.7c3.7,11.9,4.3,45.4,5.4,53.3
            		c2.4,18.4,3.6,33.5,4.6,52C2573.6,1456.7,2576.5,1502.1,2577.5,1532.5z M2521.5,1552.3c0,12.2,0.3,37.6,1.3,37.6
            		c2.8-0.2,11.5,0.8,17.5,0.2c20.8-2.6,18.8-6.8,19.2-25.7c0.5-22.7-1.4-55.5-1.3-75.7c0.1-16.7-9-99.2-11.1-117.5
            		c-1.8-15.3,1.6-26.9-6.9-40c-4.1-6.4-12.2-9.6-17.9-8.5s-19.6,5.1-21.5,5.6c-1.6,0.7,8.6,67.8,9.2,74.7
            		c2.6,28.1,9.3,53.1,10.2,81.4C2520.3,1490.1,2521.6,1535.3,2521.5,1552.3z"/>
            	<path id="dev-o" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M2444.7,1488.8c1.2,29.9,2.7,99.7,3.2,131.6
            		c0.5,31.6-2.3,67.1-4.7,98.5c-2.5,32.5-3.5,64.5-14.7,95c-4,10.7-4.7,32-39.9,32c-14.6-1.7-31.5-12-32.7-24.9
            		c-0.7-7.5-2.7-14.7-2.8-22.5c-0.2-11.1-0.5-22.3-0.2-33.3c0.7-24.9,2.3-49.9,1.2-74.8c-1-21.6-1-47.1-1.3-68.7
            		c-0.2-14-3.4-65.8-3.6-79.6c-0.3-20.7-4-40.9-5.1-61.4c-0.9-16.5-2.9-33-3.6-49.6c-1.3-29.3-4.3-54.5,8.8-80.8
            		c3.6-7.2,12.2-12.5,18.8-16.7c26.1-9.3,44.9-7.7,49.6-0.7c6.1,9.1,9.9,34.4,11.9,41.6c2.8,10,6,20.7,7.5,31.1
            		C2440.8,1432.5,2444.1,1459.5,2444.7,1488.8z M2382.6,1817.3c1.5,5.4,9,6,12.6,1.8c2.5-3,7.8-12.1,8.8-15.8c5.1-14.6,9-53.7,11-71
            		c1.7-14.8,1.3-29.9,2.7-44.6c1.9-19.2,3.2-42.4,4.2-61.6c1.1-21.5-2.1-81.1-1.8-102.6c0.2-12.3,0.8-24.7-0.3-36.8
            		c-2-21.8-5.5-43.4-7-65.2c-0.4-5.2-5.7-44.5-10.3-63.2c-2.7-13.4-16.5-11.7-20.3-11.9c-7.9-0.9-12.1,33-14.1,49.3
            		c-2.1,16.7-0.7,65,0.7,72c3,16,3.5,32.4,5,48.5c2.3,25.8,5.5,89.6,5.5,115.7c0,19.3,1.6,42.5,1.4,61.8c-0.2,18.3-1.6,36.4-2.1,54.6
            		C2378.3,1761.3,2380,1807.8,2382.6,1817.3z"/>
            	<path id="dev-l" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M2319.2,1841.6c-18.2-1.7-75.8,1.1-92.6-0.7
            		c-1.8-1-1.1-12.5,0-23.7c0.3-3.5,15.9-1.5,16-3.6c0.8-12.5,6.9-83.2,7.9-95.8c1.4-16.9,3.2-33.7,6-50.4c3-17.8,3.1-35.6,4.4-53.5
            		c0.9-11.6,1.1-72.7,1.4-91.6c0.4-22.7,2.3-33.9-1.3-56.2c-1.5-9.2-8.4-66.8-7.2-76c0.5-3.8-16.9-8.3-16.9-18.8
            		c0-1.6,53.3-13.6,53.2-12.9c2.6,17.2-8.3,21.8-7.5,26.8c1.7,11.1,4,87.9,3.7,97c-0.3,10.6,2.2,57,1.1,68.5
            		c-2.2,21.8-2.2,55-3.1,76.8c-0.9,21.2-7.1,84.4-8,89.2c-2.8,14.7-2.1,36.1-4.1,50.9c-2.1,15.4-3.9,46.9-2.9,47.1
            		c7.6,1.7,24.5,0.5,32.1,0.1c13.9,0.4,12.9-10.6,18.7-8.9C2324.3,1807.2,2321.5,1842.2,2319.2,1841.6z"/>
            	<path id="dev-e-2" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M2149.6,1691.9c-1,0.1-3.8,47.8-7.4,64.1
            		c-2.9,13.3-5.2,59.7-1.9,59.5c12.2,0.5,14.3,1.8,25.4,1.8c9.7,0,7-13.3,15.5-13.9c2.4,0.8,1.9,37.4-1,37.2
            		c-4.6,0.4-23.2-0.9-27.8-0.6c-12.2,0.7-41.8,0.9-55.4,0.5c0,0-1.1-12.1,1.3-22.8c1.1-5.1,11.9-1.4,12.2-2.9
            		c5.8-39.5,14.6-154.9,17.5-176.4c3.1-22.7,8.1-68.3,7.6-91.8c-0.1-7.3,1.9-111.3,2.2-118.6c-0.1-4.1-15.9,9.7-15.3-2.7
            		c0.3-5.4-4.7-22.8-3.5-24.3c4.8-0.8,50.6-12.6,63.2-14.7c7.6-1,22.9-10.2,25.2-10.2c4.5,0.1,7.4,44.1,5.8,47.3
            		c-0.6,1.2-19-13.2-19-13.2c-11.5,3.3-19.5,5.8-29,8.9c-2.9,1.5-3.2,47.2-3,53.4c0.9,30.2-0.4,58.2-0.5,88.4c0,21.9-2.4,33.7-4,55.5
            		c-1.7,24.6-6.5,45.9-4.9,46c37.5,1.5,22.7-13.1,35.3-11.3c3.5,2,2.8,41.1,1,42.6c-4-0.3-9.6-2.8-15.6-3.3
            		C2165.6,1689.9,2155,1691.6,2149.6,1691.9z"/>
            	<path id="dev-v" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M2016.9,1807.9c5.8,0,11.1-75.8,13.4-87.9
            		c4-20.8,8.4-71.7,9.5-76.4c6.7-28.4,14-120.5,15.6-136c0.1-1,7.4-55.2,5.3-69.6c-0.7-12.8-14.1-6.3-16.5-16.4
            		c-0.9-4.1,49.3-15.5,50.1-14.3c0.1,14.9-12.7,13.9-12.4,23.4c0.3,11.1-6.2,67-4.6,80.1c0.7,5.4-3.9,91.4-11,127.2
            		c-1.8,9-20.5,97.4-25.7,131.3c-1.7,9.8-5.3,39-9,50.7c-0.5,8.5,6,5.8,6.8,21.7c0.2,3.5-44.3,1.8-46.9,1.8
            		c-4.4-11.2,10.3-16.6,8.8-23.8c-1-4.9-3-61.3-3-66.3c0-36.9-2.5-75.2-3.7-112c-1-31.2-3.7-61.6-3.7-92.9c0-15.5-2.9-81.1-3.3-90.3
            		c-0.2-6.4-16.4-3.5-17.9-10.9c-0.8-4.2,50.1-16.6,51.6-15.1c1.4,9.2-13.2,14.1-12.3,20.6c0.7,5.4,5.3,62.5,4.3,79
            		c-1.2,20.6,3,37,3,66.7c0,13.3,1.8,82.2,2.3,106C2018.1,1721.6,2012.4,1807.3,2016.9,1807.9z"/>
            	<path id="dev-e" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M1918.8,1840.6c-11.3,0.8-56.8-1.3-58.8-1.1
            		c-3.4,0-1.3-14.4-0.5-23.2c0.1-1.3,6.7,1.3,7.4-1.1c6.1-23.6,12.4-172.7,12.2-180.2c-0.4-23.6,0-39-3.8-62.4
            		c-2.2-13.4-2.2-70-3.3-77.2c0,0-13.5,4.1-13.4,2.3c0.7-4.4-5.3-17.8-3.7-18.2c2.6,0,38.5-11.2,43.7-12.2c10.9-3.2,32.4-8.4,42-9.3
            		c1.6-0.2,2.1,34.5,0.5,39.4c-0.2,0.6-9.8-10.1-14.8-9.9c-7.4,0.3-22.3,2.7-30.2,3.6c-1.9,0.2-2.2,19.6-1.2,28.5
            		c2.9,25.4,1,51.8,3.8,77.3c4.1,36.7,2.4,61.5,0.6,98.4c-0.4,8.7-1.4,14.7,0.2,15.1c32.3-0.2,28.3-5.5,36-5.2c0,0-0.1,6.2-0.2,11.7
            		c0.1,6.4-0.3,19.5-0.3,19.5c-6.9-0.5-6-5-37.1-4.2c-2.4,0.5-2.3,6.4-4,25.9c-1.8,15.5-5.6,57.6-4,57.7c12,0.4,20.1,1.5,31.1,1.6
            		c12,0.4,12.6-10.5,18.5-10.3c1,3.9,1.8,31.1-0.5,32.8C1937.1,1841.4,1927.7,1840.5,1918.8,1840.6z"/>
            	<path id="dev-d" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M1740.7,1610c-1.2-31-3.1-35.3-3.1-35.8
            		c-0.1-1.6-4.5-32.4-4.8-34c-3.1,0.8-15.9,4.4-16.5,2c-1.2-4.8-2.9-22.6-2-23.1c9-4.4,43-14.5,53.4-16.3c3.7-0.1,26-3.1,29.4-1.6
            		c13.6,6.3,21.4,17.1,22.4,31.3c2.1,30.7,4.8,55.4,5.4,86.1c0.2,13.8,0.3,62.5-0.3,81c-0.9,25.2-2.5,50.2-7.2,75.1
            		c-3.1,16.1-9.1,31-16.8,45.2c-3.5,6.5-13,13.8-24.2,17.3c-12.1,3.8-48.5,2.7-61.6,2.7c-2-0.7,0.9-18.7,1-22.8c10.8-0.5,13-1,13-1
            		c4.9-27.3,11.9-135.7,12-152.7C1741.9,1638,1740.4,1618.2,1740.7,1610z M1802.5,1660.2c0.1-6-2.9-105.3-4.4-118.1
            		c-2.8-23.9-45.2-7.9-45.2-7.9c1.2,11.2,6.8,30.5,7.3,41.9c0.8,16,1.8,16.9,2.9,32.9c0.4,6.6,1.5,20.5,0.3,32.7
            		c-1.5,15.7-1.9,82.7-2,95.5c0,4.8,0,9-0.4,14.1c-1.1,12.4-11.7,63.9-10.8,64c10.7,0.8,26,0.2,31.6-7.9c8.3-12.1,12-38.9,12.8-41.2
            		c1.7-11.5,2.1-24.1,3.5-35.5C1800.7,1710,1803.6,1680.9,1802.5,1660.2z"/>
            	<path id="des-n" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M1172.1,1672.2c-0.7,23.9,0,141.7-1.4,153.1
            		c-0.7,7.7,10,3,11.3,13.8c0.2,1.5-57.2,3.5-57.2-0.2c0-7.6,9.2-5.6,10.6-11.5c5.6-24,7.6-91.9,9.8-101
            		c4.3-17.8-1.5-224.9-1.5-245.3c0-10.5-10.4-12.9-8.5-23.4c0.9-5.1,33.3,7.2,35,11.3c2.2,5.4,8,42.2,13.5,54.2
            		c4.4,9.6,13.8,44.7,15.5,52.4c5.1,23.8,20.3,107.5,24.7,129.9c1.2,5.9,16.5,85.4,17.7,88.7c9.4-2.5-3.1-189-2.8-202.5
            		c0.4-16.9,1.7-80.8,0.7-92.2c-1.6-4.1-9-11.7-8.9-18c0.9-2,51.2,15.3,48.6,19.6c-3.4,8-11,0.7-12.3,13.6c1.7,15.3-4,44.4-4.1,59.9
            		c-0.1,16.3,5.5,98.1,3.5,139.4c0.1,25.1,3.6,82.4-1.2,103.4c-3.8,16.5,9.6,8.7,11.3,20.3c0.3,2-58.4,4-59.8,0.3
            		c-0.9-5.9,11.7-5.3,7.2-20.8c-4.4-15.2-15.6-67.2-17.9-82.8c-2.5-17.7-11.1-34.5-13-52.2c-1.5-13.9-22.6-123.5-24.5-127.3
            		C1165,1554.4,1172.7,1649.5,1172.1,1672.2z"/>
            	<path id="des-g" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M1046.7,1434.9c-0.8,1.3-20,49.6-20.9,47.2
            		c-12.2-12.1,4-8.4-8.2-32.8c-4.4-9.9-36.3-32.3-46.9-25.8c-8.6,5.3-12,19.1-14.1,28.2c-2.6,11.3,4,60.4,4.2,73.5
            		c0,1.5-0.8,90.1-2.2,97.4c-3,16-6.7,111-10.4,137c-2.2,15.1,0.7,22,5.4,36c7,21.2,36.4,29.8,52,14.4c7.3-7.1,5.6-60.8,7.3-78.8
            		s0.3-37-2.9-36c-3.5,0-14.5-2-24.4-0.9c-0.3-9.1-14.3-26.2-7.2-29.7c15.5,0.9,67.6,2.4,82.7,0.4c3.3,1.3,1.4,20.5-2.7,27.7
            		c-0.7,8-15.3,1-16.3,5c-3.1,12.5,2.3,138.3,0.7,143.5c-25.7,1.6-15.1-21.5-25.7-11.4c-11.1,10.4-11,13.8-48.9,13.8
            		c-49.8,0-54.6-69.1-51.1-87.6c3.4-17.8,15.5-231.8,13.3-241.5c-5.1-23.6-8.3-123.4,46.5-115.6c28.4,4.1,43.1,25.7,52.3,30.2
            		C1036.9,1432.7,1050,1425.9,1046.7,1434.9z"/>
            	<path id="des-i" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M817.9,1572.5c0.3,2.4,0.1,22.8,0,27.8
            		c-0.7,25.8-2.3,72.9-2.8,88.9c-0.1,2.3-5.8,67-7.4,79.2c-1.6,12.3,0.2,35.7,0.1,40.2c-0.2,3.7,4,3.9,11.8,5.2
            		c6.5,1.2,7.2-6.5,10.8-4.5c-0.6,4.5,1.9,28.7-1.5,29.7c-24-3.7-65.2,1.1-68.1,0.3c-1.1-1.1-2.3-24.7-1.6-29.5c3.8-4,4.4,3.8,10,3.1
            		c7.5-1.5,9.9,2.6,10.5-3.1c1.7-16.7,1.6-39.9,3-56.7c1.3-15.8,8.2-142.2,8.6-152.5c0.3-8.9-0.8-28.6-0.7-38.5
            		c0.2-17.2-7.2-133.3-7.9-140.6c-1.5-15.6-0.4-48.9-0.6-50.6c0,0-3.6-2.4-7.8-4.3c-8.2-2.5-9.9,6.2-13.7,2.8
            		c1.8-4-1.5-31.6,2.3-32.2c5-0.3,25.8,5.7,40.6,12.4c11.7,5.3,7.9,3.6,20.7,8c2.3,1.1,10.8,5.4,10.2,7.8c-3.1,12-3.9,26.9-5.7,26.1
            		c-4.7-1.5,2.6-2.4-8.7-8.5l-12.4-4.7C807.4,1380.6,816.8,1563.2,817.9,1572.5z"/>
            	<path id="des-s" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M633.7,1593.6c-5-10.8-42.2-23.9-45.7-27
            		c-14.3-12.7-29.1-28.2-32.3-46.9c-1.4-8.5-7.9-85.2-7-105.4c0.1-1.3,1.3-124.5,51.9-125c49.5-0.5,61.9,46.1,63.5,61
            		c1.5,19,8.6,87.4,8.8,106.4c0.1,16.9,6,10.7,6,22.1c-1.2,3.5-38.2,3.4-41.8-0.1c-1.7-11.3,8.9,0,8.9-20.4
            		c0-13.6-2.9-101.1-3.5-114.7c-0.5-11.1-17.7-32-24.8-33.3c-8.3-1.6-26.3-0.1-31.1,19.5c-4.1,11.5-8.4,78.9-8.4,84.3
            		c-0.3,31.9,1.6,97,9.2,111.5c6.7,28.1,48.7,28.7,64.6,52.8c5.9,7.7,15.8,88.4,15.4,114.2c-0.2,6.6,10.8,148.7-51.6,150
            		s-87-72-86.6-96.3c0.3-18.6-2.2-53.2,1.9-76.3c3.9-21.7,29.1-40.7,44-40.7c6.2,0,7.5-5.3,17-12c3.1-2.2,14.3,65.5,10.7,65.2
            		c-12.7-1.2-7.2-7.3-19.4-14.8c-8.7-5.3-17-8.3-20.8-0.1c-6.4,14.1-3.9,36.3-3.9,52.7c0,13.2,23.6,88.9,51.6,88.3
            		s35.4-54.3,34.9-90.8S637,1600.8,633.7,1593.6z"/>
            	<path id="des-e" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M390.9,1837.5c-14.1,0.2-47-1.7-63.2-2.6
            		c0,0-2.3-8.4,1.4-24.7c7.6,2.2,6.5-0.6,6.6-12.9c0.8-11.5,1.1-87.4,2.2-122.6c0.2-5.8,0.6-24.6,0.5-26.3c0-1.3,1.2-60.1,2.8-65.7
            		c1.6-5.7-0.1-91.5-1.9-103.6c-0.6-3.9-5.9-97.2-5.6-105.1c0.4-12.5-1.9-96.5-1.2-108.9c1-29.3,3.4-26.6-8.4-27
            		c-0.9-13.7-1.4-31.6-0.8-31.6c18.3,0,60.6,21.5,76.7,27.6c52.2,15.8,50.4,10.3,59.1,10.9c3.1,0.6-6.7,49.1-9.6,48.6
            		c-6.4-0.7,2.6-13.5-15-21.1c-20.2-8.6-53.9-24.3-73-28.1c-2.5-0.3,1.9,105.3,2.5,116.2c1,21.2,0.3,48.6,2.4,69.8
            		c1.2,12.5,3.6,60.7,4.4,72c1.1,16.5-1.6,70.6-1.2,74.8c1.4,16.9-0.5,72.7,0.6,73.2c4.5,1.2,24.5,0.8,28.8,0.9
            		c28.8,1.2,26.8-7.5,35-7.8c1.1,0.4,1.6,39.9,0.4,39.9c-5.9,0-2.6-8.6-64.7-8.2c-1.8,0-1.2,136.5,2.2,137.5
            		c74.2,3.4,61.5-11.1,70.8-11.2c5.1-0.7,3.4,33.7,2.8,34C436.5,1837.5,404.6,1837.5,390.9,1837.5z"/>
            	<path id="des-d" style="fill-rule:evenodd;clip-rule:evenodd;fill:#FFB400;" d="M126.1,1143.7c14.1,4,43.3,12.5,57.2,17
            		c16.3,5.2,31.2,20.7,38.8,36.3c7.6,15.5,11.1,31.5,14.7,48c3.3,15.3,14.6,210.1,11.9,231.1c-2.2,16.8-6.5,184.4-7.3,203.3
            		c-1.1,27.2-12.2,123.8-42.6,142.9c-32.2,20.2-98.8,6.3-118.7,11.6c0,0-0.7-8.5,0-23.9c0.9-6.9,17.3,11.1,17.4-17.1
            		c0.2-53.8-6.2-295.7-6.2-299.6c0-114,3-286.6,2.9-296.1c1.5-45.9-15.1-24.4-16.5-32.9c-0.5-2.8,0.2-27.7,3.5-27.9
            		C83.3,1136.4,121.2,1142.4,126.1,1143.7z M201.1,1210.7c-5.6-16.7-17.2-23.3-33.5-28.2c-15.9-4.6-51.2-15-50.7-11.2
            		c0.8,6.9,0.7,61.5,0.9,71.1c0.3,16.2,2.1,171.9,2.8,182.6c1.2,18.9,0.4,132.4,1.8,151.4c0.4,5.3-1.5,123.7-1.8,126.3
            		c-1.3,16.4,0.9,102.1,0.9,102.1c21.4,6.4,21.4,6.4,43.7-2.8s37.6-42.3,39.4-55c2.7-19.4,10.7-255.5,10.7-265.3
            		C215.3,1469.3,208.4,1232.4,201.1,1210.7z"/>
            	<path id="bk-n" style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M1650.6,2036.7c-8.8,0.1-8.7-1.3-10-7
            		c-1.5-6.9-8.3-9.3-12.2-14.3c-5.4-6.8-11.8-13-18-19.1c-3.3-3.2-5.2-2.5-6.2,2c-3.4,14.9-10.6,28.4-16.3,42.4c-2,4.9-7,6.8-10.7,5
            		c-4.4-2.1-5.8-6.5-3.5-11.8c6.6-15.1,12.8-30.3,17.3-46.2c1.4-5,2-9.8,2.5-14.8c0.5-5,1.8-9.9,6.8-11.3c5.4-1.5,9.7,1.5,12.7,6.2
            		c8.6,13.5,21.8,22.8,31.3,35.6c4.9,6.7,8,6,11-2.2c4.5-12.2,13.7-21.5,19-33.1c1.7-3.8,0.6-5.4,9.8-3.2c6,2.7,3.2,4.6,3.3,7.7
            		c0,2.9-1.5,5.1-3.2,7.3c-8.6,11.1-13.2,24.2-19,36.8c-1.4,2.9-0.8,5.9-1,8.9C1664.2,2036.1,1664.2,2036.1,1650.6,2036.7z"/>
            	<path id="bk-k" style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M1120.3,1996.2c11.6,13,26.9,20.3,40.8,29.6
            		c9.6,5.8,9.6,5.8,3.6,13.5c-7,9-7,9-14.1,3.7c-0.9-0.4-1.9-0.8-2.6-1.5c-10.4-10.2-24.2-15.8-35.1-25.2c-1.8-1.5-3.7-3-5.8-4.1
            		c-8.3-4.5-11.4-3.2-13.2,6.3c-1.2,6.1-3.5,11.6-6.1,17.1c-3.4,8.2-4.4,10.6-12.8,6.9c-10.9-4.6-8.9-4.9-3.6-14.1
            		c6.6-11.8,9.8-24.9,15.9-36.9c5.5-10.9,13.1-21.3,13.4-34.5c0.1-3.9,1.7-7.1,10.9-3.9c8.8,3.1,7,5.6,5.3,9.3c-1.7,3.7-4,7-5.9,10.6
            		c-1.1,2.1-2,4.8,0.2,6.5c1.7,1.4,4,0.2,5.5-1c8-6.4,17.8-9.6,26.3-15.1c3.4-2.2,6.4-4.5,10,0.1c7.4,8.7,2.1,7.7-0.6,10.2
            		c-3.2,7.1-10.7,8.1-16.2,11.3C1130.6,1988.3,1125.3,1991.7,1120.3,1996.2z"/>
            	<path id="bk-o-2" style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M1001.8,2002c1,8.2-3.7,14.4-8.9,21
            		c-10.5,13.2-24.9,20.4-40.6,18.3c-16-2.1-31.2-8.7-39.7-25.5c-5.6-11.1-4.3-20.8,1-30.6c5.1-9.6,13-16.1,24-18.3
            		c4-0.8,11.6-1.4,14-4.6c0,0,3.8-4.4,8.3-2.8c5.4,1.9,11.1,3,16.5,4.8C992.4,1969.6,1002.8,1985,1001.8,2002z M936,1981
            		c-10.3,4.6-14.5,18.7-7.3,27.4c5,6,11,11.5,19.3,14c9.8,2.9,19,0.7,27.3-3.4c7-3.5,12.6-9.3,12-18.4c-0.7-9.7-7.5-18.3-15.8-21.4
            		C961.4,1973.9,940.9,1978.8,936,1981z"/>
            	<path id="bk-o-1" style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M728.3,2009.1c1.7-16.7,6.8-31.7,20.8-42.5
            		c6.4-4.9,13-7.6,21.3-7.1c11.3,0.7,22.2,1.6,30.8,10.3c6,6,9.4,13,9.6,21.6c0.3,13.4-3.2,25.4-13.1,34.9
            		c-5.6,5.4-9.8,12.6-19.2,13.6c-11,1.2-21-0.4-31.2-4.8c-7.9-3.4-11.9-10.5-18.2-15.4C725.6,2016.7,728.4,2012.7,728.3,2009.1z
            		 M744.8,2002.9c-0.9,3.7,1.1,7.3,4.5,10.6c4.7,4.7,10.7,7.6,16.8,8.7c4.7,0.8,10,3.8,14.7,0.9c9.2-5.8,15.6-14.4,15.9-25.4
            		c0.2-8.2-3.6-16.4-11.2-20.2C768.3,1969,746.1,1982.6,744.8,2002.9z"/>
            	<path id="bk-r" style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M627.9,1978.4c1.8,6.7-6,8.4-9.6,12.8
            		c-1,1.2-2.9,1.6-4.4,2.4c-3.1,1.8-9,1.1-9.3,5c-0.3,4.5,5.5,6.5,8.9,8.2c14.3,7,31,18.4,45.1,25.5c3.9,2-4.8,15.9-10,14.7
            		c-4.5-1-9.5-2.3-13.1-4.9c-15-11-32.4-17.8-48.3-27.1c-2.3-1.3-5.1-1.7-7.7-2.4c-7.6-1.8-9.3-1.2-9.6,6.8
            		c-0.3,6.7-4.7,9.2-8.7,12.7c-2.3,2-4.3,0.9-6.5,0c-2.8-1.2-2.9-3.4-2.3-5.9c3.5-14.7,1.2-30.1,4.9-44.8c0.9-3.7,0.9-7-0.7-10.7
            		c-1.8-4.1-2.3-8.5,0.6-12.6c1.5-2,2.9-3.3,5.8-2.7c10.3,1.9,20.5,2.4,30.9,0.4c6.3-1.2,12.7,0.9,19,1.8
            		C620.4,1958.6,627.7,1969,627.9,1978.4z M591.7,1970.9c-3.3,0.4-6.6,0.8-10,1.3c-1.3,0.2-5.8-1.4-7-0.9c-3.8,1.4-2.8,21.5,2.7,19.7
            		c13.4-4.2,7.2-1.9,22.7-7.2c3.5-1.2,8.1-2.8,8.1-6.4c0-4.1-5.1-4.5-8.5-5.5C597.1,1971.2,594.4,1971.2,591.7,1970.9z"/>
            	<path id="bk-b" style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M420.5,1946.9c7.5,2.3,14.3,0.5,21,1.7
            		c11,2,18.7,10.7,19.1,21.6c0.1,3.6-1.9,6.5-3.4,9.4c-4.5,8.6-4.2,8.1,2.2,14.6c10,10.2,13.3,20.8,4.2,34.3
            		c-2.6,3.8-6.5,5.8-10.5,7.6c-12.6,5.6-25.4,10.8-39.2,12.9c-4.9,0.8-11.8,1.7-16.3,4.6c-3.9,2.5-7,2.5-11.7,2.3
            		c-6.8-0.4-8.5-3.3-6.9-9.9c3.4-14.1,8.6-27.5,15.3-40.3c4.9-9.5,5.7-20,9-29.9c1.9-5.7,4.2-10.8,0.5-17.2c-2.2-3.8,2.2-7.5,6-9
            		C413.2,1948,417.3,1947.6,420.5,1946.9z M436.8,2005.3c-5,0.2-24.5,3.4-28.8,5.7c-3.6,1.9-12.3,25-6.7,25c2.7,0,14.3-2.4,16.9-3.2
            		c9.3-2.9,18.6-6.2,27.9-9.2c4.1-1.3,5.8-3.6,5.9-8.1c0.1-5-2.2-7.5-6.2-9.3C443,2004.9,439.9,2005.1,436.8,2005.3z M444.1,1972.4
            		c-1.7-2.6-1.7-6.9-5.8-7.4c-4.7-0.6-8.9-2.8-13.8-2.8c-4,0-6.1,1.5-7.6,5.1c-1.9,4.8-2,9.9-3,14.8c-2.3,11.2-4.7,11.2,6.1,8.7
            		c8.1-1.9,15.7-7.9,21.4-13C443,1976.5,444.2,1974.8,444.1,1972.4z"/>
            	<path id="ny-n" style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M1893.7,1997.2c-3,9.2-11.7,27.1-17.1,35.1
            		c-3,4.4-5.9,8.9-7.1,14.4c-0.6,2.8-1.7,7-6.1,7.1l-11.3-7.1c-1.7-6.7,2.9-14,6.8-18c10-10.3,13.7-23.3,17.3-36.3
            		c2.3-8.2,7.8-14.1,12.4-20.6c4.5-6.3,4.5-6.3,15.2,3.3c2.5,3.1,18.4,33.6,22.1,41.9l9.4-14.6c0,0,12.8-27.5,15.9-36.1
            		c2.9-9.7,2.9-9.7,14.6-4.7c5.8,3.2,5.8,3.2,2.8,9.4c-3.5,7.4-6,15.1-9.8,21.9c-3.8,7-7,14.4-11,21.4c-3.9,6.8-13.8,32.3-14.2,35.7
            		c-2.2,8,0.1,8-9.1,8c-7.9,0.1-6.8-2.8-7.8-6.5C1912.9,2037.1,1894.9,1997.5,1893.7,1997.2z"/>
            	<path id="us-a" style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M2774.7,1972.3c0.7,7.8,1.3,16.8,1.1,26
            		c-0.1,3.4,1.8,4.8,4.7,5.3c10.5,1.7,10.5,2.7,0.7,10.6c-5.2,4.2,0.8,11.3,1.9,16.4c2.8,13.2,8,19.5-6.7,19.5
            		c-10.7,0-9.2-3.6-9.9-9.2c-0.9-6.8-0.6-21.9-2.1-28.4c-11.1-3.6-10.1-3.1-16.2-3.7c-4.4-0.4-11.8-4.3-16.2-4.3
            		c0,0-13.2,14.5-17.5,25.4c-0.9,2.2-0.9,6.9-2.2,8.8c-1.6,2.3-20.9,2.3-23.4-1.5c-2.5-3.9,4.6-15.1,6.3-16.2
            		c3.6-6.6,35.2-41.2,39.2-45c6.2-5.9,13.2-13.3,17.4-20.8c5.4-9.5,4.2-7,10.4-6.8c6.4,0,7.5,0.4,9.8,8.3
            		C2773.9,1961.5,2774.1,1963.2,2774.7,1972.3z M2735.7,1993.9c15.2,2.8,29.7,6.5,29.7,6.5s1.9-20.8-5.8-35.7
            		C2754.6,1968.6,2739.4,1987.9,2735.7,1993.9z"/>
            	<path id="us-s" style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M2537.2,2045.4c-3.7-0.7-9.4-1.5-14.9-2.8
            		c-6.5-1.5-10.1-3-16.6-1.8c-6.3,0.7-17-3.8-16.2-14.9c0.9-12.5,2.2-6.7,6-7.4c9.5,1.7,31.5,13.4,58,5.1c3.6-1.1,3.9-3.6,1.3-6.1
            		c-2.7-2.5-5.5-4.9-8.9-6.5c-3.9-1.9-7.3-4.8-10.9-7c-10.3-6.1-10-14.9-8-24.5c0.9-4.5,11.1-13,17.3-13.9s12.3-2.8,37.7-3.9
            		c1.2,0,4.8,9,3.9,9.7c-4.6,3.5-7.8,5.8-13.8,5.5c-6.7-0.3-18.5,0.7-23.7,5c-2.5,2.1,1.7,10.3,15.7,14.4
            		c10.1,2.3,16.9,16.3,16.3,24.5c-0.6,8-6,17.6-14.4,19.8C2557.1,2042.8,2548.3,2045.1,2537.2,2045.4z"/>
            	<path style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M2325.7,1966.4c3-13.2,3.5-12.6,16.4-8.9
            		c4.1,1.2,4.1,1.2,2.3,7.5c-1.5,4.9-4.4,19.2-6,24c-3.3,9.9-0.3,18.8,4,27.2c4.9,9.3,18.3,8.2,24-1.6c7.1-12.3,10.7-25.9,14.1-39.6
            		c0.5-2,0.9-3.9,1.3-5.9c2.7-11.7,2.7-11.7,13.5-9.2c10.9,2.5,9.6,3,7.7,12.6c-0.6,3.2-1.2,6.8-2.7,9.4
            		c-6.9,12.4-11.5,25.7-16.9,38.7c-5.6,13.5-23.8,24.5-37.4,20.7c-7.7-2.1-13.1-8.8-19-14.3C2312.5,2013.3,2323.6,1976,2325.7,1966.4
            		z"/>
            	<path style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M2032.6,2061c-6.7,0.1-9.2-2.4-6.9-8.4
            		c4.5-11.6,7.2-23.6,11.6-35.2c3.9-10.3,2.6-14.9-6.2-21.7c-6.9-5.3-13.7-10.9-20.2-16.7c-5.8-5.2-5.7-9.9-0.6-14.4
            		c5.3-4.7,11.6-4.5,15.5,1.4c2.8,4.2,6.7,6.6,10.7,8.9c3.6,2,7.3,4,9.6,7.2c3.5,4.9,6.5,3.4,10.1,0.6c5.4-4.2,7.5-11,12.2-15.8
            		c3.7-3.8,7.6-6.7,12.8-7.5c4.4-0.6,8.3,1.2,10,5.3c1.5,3.8-1.5,6.4-4.3,8.3c-11.8,8.4-19.4,20.2-25.7,32.9
            		c-6.2,12.3-10.5,25.1-12.2,38.9C2047.7,2055.3,2041.3,2060.8,2032.6,2061z"/>
            	<path style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M1414.7,1960.6c3,0.1,5.4,1,7.4,3.2
            		c6.5,7.4,15.6,10.2,24.1,14.1c2,0.9,8.5,7.2,9.9,6c6.5-5.3,22.6-16,28.5-22.3c4.5-4.8,8.6-4.9,12.1-1.3c3.1,3.2,2.2,9.6-2.9,13.1
            		c-7.8,5.4-15,11.4-22,17.6c-13.1,11.5-23.8,24.5-25.6,43.1c-0.7,7.1-5.1,13.1-12.5,15.9c-3.1,1.2-6,1.5-8.4-1.1
            		c-2.1-2.3-3.7-4.9-2.6-8.2c0.1-0.3,0.2-0.7,0.3-1c5.4-10.2,7-22.1,13.8-31.9c5.8-8.3,5.5-11.4-3.2-16c-8.4-4.4-15.4-10.8-23.8-15.1
            		c-4.1-2.1-7.6-4.7-5.8-10.3C1405.8,1961.1,1410.6,1961.5,1414.7,1960.6z"/>
            	<path style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M1283.1,1969.3c-4.7,8-3.6,19.3-7.5,29.5
            		c-1.9,5-3.1,10.3-4.3,15.6c-0.7,3.1,0.5,5.6,4,5.7c13.4,0.4,26,7.6,39.8,4.8c1-0.2,2-0.1,3,0c4.5,0.7,9.1,5.1,8.6,8.2
            		c-0.9,5.9-6.7,11.4-11.6,10.8c-20.6-2.6-48.1-5-68.9-5.8c-4.3-0.3-8.9-0.7-0.4-12.7c3-4,10.7-21.9,12.7-26.8
            		c1.8-4.7,4.2-9.2,4.8-14.3c0.4-3.7,1-6.9-0.2-10.8c2.5-14.1,1.5-15.6,14-13.8C1286,1961.3,1283.8,1962.9,1283.1,1969.3z"/>
            	<path style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M1717.4,2048.4c-2.5,11-12.2,22.2-16.2,19.8
            		c-2.6-2.8,3.4-5.5,4.8-14.3c3.2-20.4-9.2-12.8-13.5-15.6c-3.9-2.4-6.2-5.7-4.9-10.4c1.3-4.3,4.6-6.9,8.9-7.8c4.5-1,9,1.2,11.2,5.2
            		C1710.8,2035.1,1719.5,2031.9,1717.4,2048.4z"/>
            	<path style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M2411.4,2040.5c-5.5,2.7-7.9,2.1-9.4,1.4c-3.4-1.5-5.7-4-5.1-8
            		c0.6-3.7,3.1-6.1,6.5-7.3c3.6-1.3,7.5,0,9.7,3.1C2417.9,2036.4,2415,2037.2,2411.4,2040.5z"/>
            	<path style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M2601.6,2031c2,5.4,1.1,7.5,0.2,8.9c-2,3-4.7,4.7-8.5,3.6
            		c-3.5-1-5.6-3.6-6.4-6.9c-0.8-3.4,1-6.9,4.3-8.5C2598.4,2024.5,2598.8,2027.2,2601.6,2031z"/>
            	<path style="fill-rule:evenodd;clip-rule:evenodd;fill:#D8D8D8;" d="M2807.2,2031.4c3.7,2.6,4,4.4,3.9,5.7
            		c-0.2,2.8-1.5,5.2-4.8,6.3c-3.1,1-5.7,0.2-7.7-1.6c-2-1.9-2.2-5-0.4-7.5C2802,2028.6,2803.5,2030.2,2807.2,2031.4z"/>
            	<g id="ampersand">
            		<path style="fill-rule:evenodd;clip-rule:evenodd;fill:#F9F9F9;" d="M1445.7,1604.9c0,0-21.7-10.2-24-37.3
            			c-2.7-31.7,23.3-58.3,62-58.3c20.6,0,39.1,15.8,41.3,26.3c2,9.7-1.2,19.5-2.7,26.3c-12,4.8-32.6,0.5-34-5.3
            			c-1.1-4.3,19.7-11.1,16-22.3c-2.5-7.8-19-11.3-33.3-9.3c-15.5,2.2-43.3,57.9,1.6,70.6c13.4,3.8,19.4,3.7,19,13
            			c-0.3,8.4-6.4,10.4-18.6,10.4s-56.9,26.9-66,44c-32,60.3-27,149.2,96.2,146.4c85-2,69.9-151.8,69.1-155.4
            			c-0.8-1.9-41-0.7-65.6,10.3c-6.1,2.7-24.4,23.7-13.7,39.7c6.7,10,21.9,8.2,25.7,7c14.3-4.3,2.9-21.7,9.3-22c2.3-0.1,22.3,14,6,29
            			c-9.1,8.4-36.2,9.5-45.5,0.8c-26.2-24.3-6.2-85.5,54.4-86.4c7.8-0.1,31.8-2.6,39.4-1.7c15.6,1.8,58,3.3,64.3-24
            			s-6.8-42.9-15.7-46.7c-12.8-6.3-28.4-4.6-37,0.3c-25.1,14.4-15.4,44,9.7,34.7c5.7-24.7,39,9.7-6.3,16c-8,1.1-22-2.3-26.8-9.8
            			c-5.5-6.3-8.3-17.6-6.7-24.5c3.7-16.2,15.6-24.2,32.4-29.4c16.4-5.1,32.9-4.3,46.1,3.9c32.6,19.5,30.7,76.9,2.6,92.5
            			c-15.7,8.7-20.1,13.6-45.7,12.3c-2,1,1.6,25,2,55.3c0.2,16.3,16.6,99.1-88.1,118.9c-48.7,9.2-111.2,5.3-135.3-44.7
            			C1312.4,1649.4,1445.7,1604.9,1445.7,1604.9z"/>
            	</g>
            </g>
            </svg>
            <figcaption>
                An embedded SVG version of the final(ish) logo. SVG is amazing
            </figcation>
        </figure>
        <p>
            I’m looking forward to working with the logo more. Keeping
            it vector was important for me because I want to display it using SVG.
            I also think there will be some interesting things to do with it using
            CSS transitions and animations further down the road.
        </p>
        <p>
            <i>Thanks for reading</i>
        </p>
