---
tags: post
layout: "layouts/article.njk"
highlightSyntax: true
title: "New ColorMe Features"
date: "2017-01-18"
meta:
  description: After two weeks of usage and great feedback, I made a handful of bug fixes and feature additions to the tiny color tweaker that could.
  image: /articles/assets/post-image-colorme-updates-social.png
---

<p class="entry-intro">
  Since releasing it two weeks ago, <a href="https://colorme.io">ColorMe</a> has had time to simmer and I’ve gotten a bunch of great feedback. In that time I’ve made improvements and feature additions. New features include; support for <code>hsl(a)</code> and <code>rrggbbaa</code> colors. Red, green, and blue color adjusters. And the option to choose the format of the output color.
</p>
<p>
  The first updates I made I snuck in the day after release. Those were improvements to the color adjuster sliders for touch devices. Or more accurate, devices without <code>hover</code> support. I knew the initial design had usability issues on mobile, but decided to ship it and iterate.
</p>
<p>
  The main problem was the horizontal scrolling interfering with the range sliders. The thumb of the sliders was too hard to get a hold of with a finger. And it was tough to adjust the slider instead of scrolling horizontal.
  For this first update I didn't change the UI completely for touch devices. For now I only increased the size of the thumb on the range sliders in <a href="https://github.com/tylergaw/colorme/pull/4">this pull request</a>.
</p>
<figure>
  <img src="https://tylergaw.com/articles/assets/post-image-colorme-updates-touch-support.png" alt="A screenshot of touch device use of color adjusters on ColorMe" />
  <figcaption>
    The new size of an inactive and an active thumb on touch devices. It looks odd here, but easier to see and handle when you’re using a finger instead of a mouse pointer.
  </figcation>
</figure>
<p>
  By default the CSS targets all devices. The range slider thumb is large. Almost comical in size and off center vertically when active. It looks strange in a screenshot, but the larger size and y-offset make it easier to control when using a finger.
</p>
<pre><code class="language-css">.adjusterValRange::-webkit-slider-thumb {
  ...
  height: 1.6rem;
  margin-top: -0.8rem;
  width: 1.6rem;
}

.adjusterValRange::-webkit-slider-thumb:hover,
.adjusterValRange::-webkit-slider-thumb:active {
margin-top: -1.8rem;
height: 2.5rem;
width: 2.5rem;
}</code></pre>

<p>
  To decrease the thumb size on devices with <code>hover</code> support , I used the <code>hover</code> media query available in <a href="https://www.w3.org/TR/mediaqueries-4/#hover">Media Queries Level 4</a>.
</p>
<pre><code class="language-css">@media (hover) {
  .adjusterValRange::-webkit-slider-thumb {
    ...
    height: 0.75rem;
    margin-top: -0.3rem;
    width: 0.75rem;
  }

.adjusterValRange::-webkit-slider-thumb:hover,
.adjusterValRange::-webkit-slider-thumb:active {
margin-top: -0.5rem;
height: 1.1rem;
width: 1.1rem;
}
}</code></pre>

<p>
  I’m a huge fan of using the <code>hover</code> media query instead of relying on screen size. The issue isn’t caused because the screen is too narrow. It’s caused by not having the fine control a mouse and cursor provide. The new media query isn’t available in all browsers yet, but support is good enough for these purposes.
</p>
<p>
  You can see the full CSS for the adjuster range sliders in <code><a href="https://github.com/tylergaw/colorme/blob/2017-01-17T22.58.04/src/components/Adjuster/Adjuster.css#L102">Adjuster.css</a></code>.
</p>
<p>
  Usability of the adjusters on touch devices still has room for improvement. There’s an <a href="https://github.com/tylergaw/colorme/issues/5">open issue</a> about it in the repo. Along with the ideas there, I have an alternate UI I’d like to try out. That will likely be the next round of changes I make to the project.
</p>

<h2>Red, green, and blue adjusters</h2>
<figure>
  <img src="https://tylergaw.com/articles/assets/post-image-colorme-updates-rgb-adjusters.gif" alt="An animated gif showing red, green, and blue color adjusters ColorMe" />
  <figcaption>
    Adjust the red, green, and blue channels.
  </figcation>
</figure>
<p>
  In the first release I also left out three of the available <a href="https://drafts.csswg.org/css-color/#modifying-colors">color adjusters</a>. Red, green, and blue. Those are in place now. They do what they say on package. Each one adjusts that single channel. Could be helpful for finding that perfect reddish-greenish-blue. Or for finding a good complementary color.
</p>

<h2>New supported formats</h2>
<figure>
  <img src="https://tylergaw.com/articles/assets/post-image-colorme-updates-formats.gif" alt="An animated gif showing new format inputs in ColorMe" />
  <figcaption>
    <code>hsl(a)</code> and <code>rrggbbaa</code> formats now supported.
  </figcation>
</figure>
<p>
  One of the first bits of feedback I got was from my coworker, <a href="https://twitter.com/thefivetoes">Justin</a>. He said ColorMe should support <code>rrggbbaa</code> colors for the base color. I’d never used them before so I took some time to educate myself. If they’re new to you too, read <a href="https://hashnode.com/post/understanding-rrggbbaa-color-notation-cisvdr52x088fwt53h1drf6m2">this post</a>. Then play with them in <a href="https://colorme.io?color=ff0000af">ColorMe</a> to get a better feel how they work. I’ve been using the alpha adjuster to go through each value to see what the percentage is in hex. It’s still taking me some time to think about alpha values as hex, but I'm a fan. You should give it a try if you haven’t already.
</p>
<p>
  I also added support for <code>hsl(a)</code> base colors. This was a no-brainer. It just didn't make the cut for first release.
</p>

<h2>Choosing output color format</h2>
<figure>
  <img src="https://tylergaw.com/articles/assets/post-image-colorme-updates-format-select.gif" alt="An animated gif showing new format selection in ColorMe" />
  <figcaption>
    You can now choose the output color format.
  </figcation>
</figure>
<p>
  OK, this is a fun one! Also the one that required the most effort. A request I got was the ability to see the output color in <code>hex</code> or <code>hsl(a)</code> format instead of only <code>rgb(a)</code>. This was also something I’d been wanting. So I took the idea and ran with it.
</p>
<p>
  You now have the option to choose the format for the output color. There are up to seven different formats depending on the color. The full list of formats is; hex, hex shorthand, rrggbbaa, rrggbbaa shorthand, rgb(a), hsl(a), and keyword. Depending on the base color some of them are available and some aren’t.
</p>
<p>
  When you choose a format, ColorMe will do its best to hold on to your selection. Sometimes though there's no way to display a color in a certain format. For example; say you enter the color <code>red</code>. The output format is "keyword". Now, say you adjust the <code>alpha</code> value to 90%. There is no hex or keyword format for the new color. In that case ColorMe switches to the <code>rgba</code> format. It also disables the hex, hex shorthand, rrggbbaa shorthand and keyword formats because those aren't available. In the UI, this just happen for you. React makes short work out of maintaining view layer updates. Behind the scenes there’s a lot of logic to determining what formats work for each color.
</p>
<p>
  If you’re interested in that logic, have a look at the <code>getColorFormats</code> function in <code><a href="https://github.com/tylergaw/colorme/blob/2017-01-17T22.58.04/src/utils/color.js#L232">utils/color.js</a></code>. The code there isn’t clever. Most of it is <code>if</code> statements representing what I knew should be true about each format. Because this type of logic can be brittle when making changes, I also wrote a battery of <a href="https://github.com/tylergaw/colorme/blob/2017-01-17T22.58.04/src/utils/__tests__/color.test.js#L385">tests</a> to let me know when I break things.
</p>

<h2>A bug fix and open-source sleuthing</h2>
<p>
  As I was tinkering with the UI, I hit one of those voodoo, ghost-looking bugs. After fiddling with the knobs a while longer, I saw the pattern and was able to reproduce the <a href="https://github.com/tylergaw/colorme/issues/3">issue</a>.
</p>
<p>
  When using the <code>alpha</code> adjuster with the <code>tint</code>, <code>shade</code>, or <code>contrast</code> adjusters, the alpha value was wrong. For example, this code;
</p>
<pre><code class="language-css">color(red a(10%) tint(50%))</code></pre>
<p>
  produced:
</p>
<pre><code class="language-css">rgba(255, 128, 128, 0.19999999999999996)</code></pre>
<p>
  when I expected it to produce:
</p>
<pre><code class="language-css">rgba(255, 128, 128, 0.1)</code></pre>
<p>
  First I made sure my code wasn't up to anything fishy. Then started looking at my dependencies. The unexpected results were coming from the the <a href="https://github.com/ianstormtaylor/css-color-function">css-color-function</a> package. To complicate things more, the problematic code didn't end in css-color-function. It was its use of another <a href="https://github.com/Qix-/color">color package</a>.
</p>
<p>
  css-color-function uses the <code>mix</code> function of that color package for <code>tint</code>, <code>shade</code>, and <code>contrast</code> adjusters. The <code>Color.mix</code> function was ported from Sass. In Sass, the <code>mix</code> function not only mixes color channels, it also mixes the alpha channel.
</p>
<blockquote>
  <p>
    The opacity of the colors is also considered when weighting the components.
  </p>
  <cite>
    <a href="http://sass-lang.com/documentation/Sass/Script/Functions.html#mix-instance_method">
      From the Sass docs on the <code>mix</code> function
    </a>
  </cite>
</blockquote>
<p>
  As far as I can tell, this isn't the intended behavior of the color function adjusters. For ColorMe, I forked css-color-function and modified its <code>blend</code> method. The problematic adjusters use that method. What I did was take the alpha value out of play before mixing colors. Then put it back when finished. Here's my updated version of the <code>blend</code> method:
</p>
<pre><code class="language-javascript">exports.blend = function (color, args) {
  var targetAlpha = color.alpha();

// Reset the alpha value to one. This is required because color.mix mixes
// the alpha value as well as rgb values. For blend() purposes, that's not
// what we want.
color.alpha(1);

var other = new Color(args[0].value);
var percentage = 1 - parseInt(args[1].value, 10) / 100;

// Finally set the alpha value of the mixed color to the target value.
color.mix(other, percentage).alpha(targetAlpha);
};</code></pre>

<p>
  ColorMe is now using <a href="https://github.com/tylergaw/css-color-function/tree/tg-ignore-alpha-on-mix">my fork</a> of css-color-function. I opened a <a href="https://github.com/ianstormtaylor/css-color-function/pull/26">pull request</a> to get the changes the original fork. I also added more detail about the cause and solution in the description of that PR.
</p>
<h3>Pull requests beget pull requests</h3>
<p>
  When I started pulling at this thread I found two other projects affected by it. I'm sure there are others. I opened a <a href="https://github.com/postcss/postcss-color-function/pull/33">pull request</a> in postcss-color-function and <a href="https://github.com/MoOx/postcss-cssnext/issues/337">reported the problem</a> in postcss-cssnext.
</p>

<h2>More to come</h2>
<p>
  I had a lot fun with these updates, hope folks find them useful. As said I have more ideas for future ColorMe updates. And as always if you see issues or have ideas, <a href="https://github.com/tylergaw/colorme/issues">open an issue</a>.
</p>
